Skip to contents

Check whether a certain package is required for a task. This includes the packages listed under suggestions in the description file. The user will be asked whether a package should be installed or not.

Usage

check_required_package(package)

Arguments

package

The name of the required package.

Value

Returns TRUE or FALSE.