| dummy_data | R Documentation |
The dummy data frame contains a few randomly generated variables like year, sex, age, income and weight to test out functionalities. It can be generated with the desired number of observations.
dummy_data(
no_obs = 25000,
insert_na = TRUE,
monitor = .qol_options[["monitor"]]
)
no_obs |
Number of observations. |
insert_na |
TRUE by default. Inserts random NA values into variables. |
monitor |
FALSE by default. If TRUE outputs two charts to visualize the functions time consumption. |
Returns a dummy data table.
my_data <- dummy_data(1000)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.