View source: R/small_helpers.R
| get_integer_length | R Documentation |
Get the number of digits of an integer variable.
get_integer_length(variable)
variable |
The integer variable from which to get the length. |
Returns a vector with the number of digits places.
# Example data frame
my_data <- dummy_data(100)
my_data[["age_length"]] <- get_integer_length(my_data[["age"]])
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.