Can rename one or more existing variable names into the corresponding new variable names in one go.
Examples
# Example data frame
my_data <- dummy_data(10)
# Rename multiple variables at once
new_names_df <- my_data |> rename_multi("sex" = "var1",
"age" = "var2",
"state" = "var3")