Build your own theme by just setting up the colors for the different parts of RStudio. A theme file will be exported which can be added by going to:
Tools -> Global Options -> Appearance -> Add
build_rstheme(
file_path,
theme_name = "qol_green",
dark_theme = TRUE,
editor_background = "#062625",
editor_headline = "#3B3B3B",
editor_font = "#C3B79D",
toolbar = "#2E2E2E",
tab = "#3B3B3B",
selected_tab = "#062625",
line_number = "#C3B79D",
print_margin = "#3B3B3B",
cursor = "#CCCCCC",
selection = "#1B436E",
smart_highlight = "#3686dc",
bracket_highlight = "#595959",
active_line = "#202324",
whitespace = "#CCCCCC",
debug_line = "#F18889",
scrollbar = "#3B3B3B",
scrollbar_hover = "#595959",
scrollbar_active = "#BFBFBF",
class_name = "#BEDD1A",
keyword = "#FFC90E",
language_constant = "#FFC90E",
function_name = "#C3B79D",
numeric = "#C93F3F",
string = "#63C2C9",
regex = "#E8E6E3",
variable = "#E8E6E3",
comment = "#32CD32",
symbol = "#C3B79D",
console_code = "#C3B79D",
markdown_code = "#083332"
)Saves a complete theme file.
The path to which the theme file should be saved.
The themes name.
Handles some elements not covered with the other parameters.
Base background color in the editor.
Mostly used for the headlines of the environment panel.
Base font color of the editor.
Base toolbar and frame color.
Color of inactive tabs.
Color of active tabs.
The color of the line numbers on the left.
Color of the vertical line showing the print margin.
Cursor color.
The background color of the current selection.
Background color of smart highlighted words.
Background color of highlighted bracket pairs.
Color for the active line the cursor is in.
Color for whitespace characters.
Color of the current debug line.
Color of the scrollbars.
Highlight color when hovering over a scrollbar.
Highlight color when clicking on a scrollbar.
Code color for class names (like package names).
Code color for fixed keywords (like function, if, else).
Code color for language constants (like the @ keywords).
Code color for base and package functions.
Code color for numeric values.
Code color for string values.
Code color for regex expressions.
Code color for variables, parameters and arguments.
Code color for comments.
Code Color of symbols (like <-, brackets).
Color of executed Code in the Console.
Background color of code passages in a markdown file.
In the 'SAS Enterprise Guide' the user is able to not only choose a given theme, but to also pick the colors for the different parts of the editor by themselves. Everyone has a different taste of what colors look pleasing to the eyes, so you should be able to choose them by yourself.
# Example function
build_rstheme("C:/My Path/", "My theme",
editor_background = "#417291",
editor_headline = "#602BCA",
editor_font = "#C75C48")
Run the code above in your browser using DataLab