Check whether a certain package is required for a task. This includes the packages listed under suggestions in the description file. The user will be asked whether a package should be installed or not.
Check whether a certain package is required for a task. This includes the packages listed under suggestions in the description file. The user will be asked whether a package should be installed or not.