The dummy data frame contains a few randomly generated variables like year, sex,
age, income and weight to test out functionalities. It can be generated with the desired
number of observations.
Usage
dummy_data(no_obs, monitor = FALSE)
Value
Returns a dummy data table.
Arguments
no_obs
Number of observations.
monitor
FALSE by default. If TRUE outputs two charts to visualize the functions time consumption.