libname() checks if a given path exists and writes a message in the console accordingly.
Optional all files from the given path can be retrieved as a named character vector.
Arguments
- path
A folder path.
- get_files
FALSE by default. If TRUE returns a named character vector containing file paths.
- extensions
Specify file extensions to be kept in the list when retrieving files.
- recursive
FALSE by default. If TRUE scans the provided folder for additional files inside sub folders. Only work in combination with get_files = TRUE.